# AudioAI
[![PyPI version shields.io](https://img.shields.io/pypi/v/anonfile)](https://pypi.python.org/pypi/anonfile/)
[![CI](https://github.com/nstrydom2/anonfile-api/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/nstrydom2/anonfile-api/actions/workflows/python-package.yml)
[![PyPI download total](https://img.shields.io/pypi/dm/anonfile)](https://pypi.python.org/pypi/anonfile/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/anonfile)](https://pypi.python.org/pypi/anonfile/)
[![PyPI license](https://img.shields.io/pypi/l/anonfile)](https://pypi.python.org/pypi/anonfile/)

A library to create audio files from text, audio to text and voice typing(only in english at the moment)

This Python package was created to make more easy to create audio files from text, audio to text and voice typing. The goal of
the project is to create an intuitive library for everyone can do this without paying.

## Getting Started

These instructions will get you a copy of the project up and running on your local
machine for development and testing purposes. See deployment for notes on how to
deploy the project on a live system.

## Prerequisites to run this application

 Python 3.7+ [Click here to download](https://www.python.org/ftp/python/3.10.7/python-3.10.7-amd64.exe)
 #### Speech Recognition 3.8.1+
 ```bash
pip install SpeechRecognition
```
 #### gTTS 3.8.1+
 ```bash
pip install gTTS
```

### Installing

To install the library is as simple as running

```bash
pip install AudioAI
```
in the command line

Navigate to [tags on this repository](https://github.com/mariodaniely2003/AudioAI/tags)
to see all available versions.

## Authors

| Name             | Mail Address                | GitHub Profile                                |
|------------------|-----------------------------|-----------------------------------------------|
| Mario Salamanca  | python@mariosalamanca.pt    | [mariodaniely2003](https://github.com/mariodaniely2003)|

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for more details.
